---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- The following copyright must be included in all software utilising
-- this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
--
--
with System ;
with X_Types ;
package Pex_Constants is
    use X_Types ;
    
    Pex_Precision : constant := 6 ;
--    Pex_Precision : constant := 15 ;
    Fp_Size       : constant := 32 ;
--    Fp_Size       : constant := 64 ;
    Fp_End        : constant := Fp_Size - 1 ;
    Fp            : constant := (Fp_Size/System.Storage_Unit) / X_32_Bits;
end Pex_Constants ;

--
with Pex_Constants ;
with X_Types ;
generic 

    type Coordinate_Component_Type is digits <>;

package Pex_Coordinate_System is

    use X_Types ;
    use Pex_Constants ;
    
    type Point_3 is
    record
        X : Coordinate_Component_Type;
        Y : Coordinate_Component_Type;
        Z : Coordinate_Component_Type;
    end record;

    type Point_2 is
    record
        X : Coordinate_Component_Type;
        Y : Coordinate_Component_Type;
    end record;

    type Point_4 is
    record
        X : Coordinate_Component_Type;
        Y : Coordinate_Component_Type;
        Z : Coordinate_Component_Type;
        W : Coordinate_Component_Type;
    end record;

    type Point_List_3 is array (Positive range <>) of Point_3;

    type Point_List_2 is array (Positive range <>) of Point_2;

    type Point_List_4 is array (Positive range <>) of Point_4;
    
    type Access_Point_List_3 is access Point_List_3;

    type Access_Point_List_2 is access Point_List_2;

    type Access_Point_List_4 is access Point_List_4;
    
    type List_Of_Point_List_3 is array (Positive range <>) of
        Access_Point_List_3;

    type List_Of_Point_List_2 is array (Positive range <>) of
        Access_Point_List_2;

    type List_Of_Point_List_4 is array (Positive range <>) of
        Access_Point_List_4;

    type Access_List_Of_Point_List_3 is access List_Of_Point_List_3;

    type Access_List_Of_Point_List_2 is access List_Of_Point_List_2;

    type Access_List_Of_Point_List_4 is access List_Of_Point_List_4;

    type Vector_3 is new Point_3;

    type Vector_Pair_3 is array (1..2) of Vector_3;

    type Vector_2 is new Point_2;

    type Vector_Pair_2 is array (1..2) of Vector_2;

    type Rectangular_Region_3 is 
    record
        Xmin : Coordinate_Component_Type;
        Xmax : Coordinate_Component_Type;
        Ymin : Coordinate_Component_Type;
        Ymax : Coordinate_Component_Type;
        Zmin : Coordinate_Component_Type;
        Zmax : Coordinate_Component_Type;
    end record;

    for Rectangular_Region_3 use
    record
        Xmin   at 0      * X_32_Bits range  0 .. Fp_End;
        Ymin   at 1 * Fp * X_32_Bits range  0 .. Fp_End;
        Zmin   at 2 * Fp * X_32_Bits range  0 .. Fp_End;
        Xmax   at 3 * Fp * X_32_Bits range  0 .. Fp_End;
        Ymax   at 4 * Fp * X_32_Bits range  0 .. Fp_End;
        Zmax   at 5 * Fp * X_32_Bits range  0 .. Fp_End;
    end record;

    type Rectangular_Region_2 is 
    record
        Xmin : Coordinate_Component_Type;
        Xmax : Coordinate_Component_Type;
        Ymin : Coordinate_Component_Type;
        Ymax : Coordinate_Component_Type;
    end record;

    for Rectangular_Region_2 use
    record
        Xmin   at 0      * X_32_Bits range  0 .. Fp_End;
        Ymin   at 1 * Fp * X_32_Bits range  0 .. Fp_End;
        Xmax   at 2 * Fp * X_32_Bits range  0 .. Fp_End;
        Ymax   at 3 * Fp * X_32_Bits range  0 .. Fp_End;
    end record;

    type Half_Space_3 is 
    record
        Reference_Position : Point_3;
        Acceptance_Normal  : Vector_3;
    end record;

    type Half_Space_2 is 
    record
        Reference_Position : Point_2;
        Acceptance_Normal  : Vector_2;
    end record;

    type Half_Space_List_3 is array (Positive range <>) of Half_Space_3;

    type Half_Space_List_2 is array (Positive range <>) of Half_Space_2;

    type Access_Half_Space_List_3 is access Half_Space_List_3;

    type Access_Half_Space_List_2 is access Half_Space_List_2;

    type Magnitude_Base_Type is digits Pex_Precision;

    subtype Magnitude is Magnitude_Base_Type range
        Coordinate_Component_Type'Safe_Small ..
        Coordinate_Component_Type'Safe_Large;

    type Size_3 is
    record
        XAxis : Magnitude;
        YAxis : Magnitude;
        ZAxis : Magnitude;
    end record;

    type Size_2 is
    record
        XAxis : Magnitude;
        YAxis : Magnitude;
    end record;

    type Range_Of_Magnitude is
    record
        Min : Magnitude;
        Max : Magnitude;
    end record;

end Pex_Coordinate_System;
