---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
--  
--   Package : Pex_Fonts
--  
--   Version :
--  
--   Function : PEX Fonts functions
--  
--   Section 12.1 -- PEX Font Resource Management
--   Open_Font          
--   Close_Font
--  
--   Section 12.2 -- PEX Font Inquiry
--   Query_Font              
--   List_Fonts              
--   List_Fonts_With_Info         
--   Query_Text_Extents      
--  
--  
with X_Types;
with Pex_Types;
--  
package Pex_Fonts is 
--  
    use Pex_Types;
--  
--   Section 12.1 -- PEX Font Resource Management
-- 
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Open_Font
    --
    --  <Description>
    --
    --  This request loads the specified PEX font, if necessary,
    --  and associates identifier Font_Id with it. The font name
    --  should use the ISO Latin-1 encoding, and upper/lower case
    --  does not matter. PEX fonts are not associated with a
    --  particular screen, and can be used with any renderer or
    --  PHIGS workstation resources. An error will be generated
    --  if the specified font is not "PEX usable", that is, it is
    --  not capable of supporting the full range of PEX text
    --  attributes. 
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Font_Name  : The name of the font.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Name is raised if the specified font could not be loaded.
    --
    --  <Called By>
    --
    --  External.
    --
    --=====================================================================

    function Open_Font ( Display_Id : in X_Types.Display;
                         Font_Name  : in String) return Font;

    --=====================================================================
    --  <Subprogram Name>
    --
    --  Close_Font
    --
    --  <Description>
    --
    --  This request deletes the association between the resource
    --  ID and the PEX font. The PEX font itself will be freed
    --  when no other resource references it.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Font_Id    : The associated Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Font is raised if the font is undefined.
    --
    --  <Called By>
    --
    --  External.
    --
    --=====================================================================

    procedure Close_Font ( Display_Id : in X_Types.Display;
                           Font_Id    : in Font);
--
--  Section 12.2 -- PEX Font Inquiry
--

    --=======================================================================
    --  <Subprogram Name>
    --
    --  Query_Font
    --
    --  <Description>
    --
    --  This request generates a reply which contains the logical
    --  information about a PEX font. 
    --  This procedure returns the Font_Record, which contains information
    --  associated with the font. Use Free_Font_Info to free this structure.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Font_Id    : The associated Id.
    --  Font_Info  : Associated font information.
    --
    --  <Called By>
    --
    --  External.
    --
    --=======================================================================

    function Query_Font ( Display_Id : in X_Types.Display;
                          Font_Id    : in Font) return Font_Record ;

    --=======================================================================
    --  <Subprogram Name>
    --
    --  List_Fonts
    --
    --  <Description>
    --
    --  This function returns a list of font names that match the string
    --  passed as the pattern argument. The length of the list passed
    --  determines the maximum number returned. The length of the returned
    --  list is the actual number found.(--Hrt)
    --  Like X11 ListFonts except that this request only returns
    --  the names of fonts that can support the full range of PEX
    --  text attributes (i.e., those fonts that are "PEX
    --  usable")This list may or may not contain some of the same
    --  fonts returned by the X11 ListFonts request. This request
    --  returns a list of at most max_names entries, each of
    --  which contains information about a font matching the
    --  pattern . Pattern is a string that uses the ISO Latin-1
    --  encoding, and upper/lower case does not matter. In the
    --  pattern, the '?' character (octal value 77)will match any
    --  single character, and the character '*' (octal value
    --  52)will match any number of characters. The returned
    --  names are in lower case, and are also ISO Latin-1 encoded
    --  strings.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Pattern    : The name(s) to be searched.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Name is raised if no names are found matching the pattern.
    --
    --  <Called By>
    --
    --  External.
    --
    --=======================================================================

    procedure List_Fonts ( Display_Id : in X_Types.Display;
                           Pattern    : in String;
                           Names      : in out String_List) ;

    --=======================================================================
    --  <Subprogram Name>
    --
    --  List_Fonts_With_Info
    --
    --  <Description>
    --
    --  This procedure returns a list of font names that match the specified
    --  pattern and their associated font information. The list of names is
    --  limited to the length of the Names_List. The information returned for
    --  each font is identical to what Load_Query_Font would return, except
    --  that per-character metrics are not returned. Note that Names_List and
    --  Font_Info_List are dynamic. Use .Length to determine the length of the
    --  returned lists.
    --
    --  Use Free_Font_Names to free the Names_List. Use Free_Font_Info to free
    --  the Font_Info_List.(--Hrt)
    --  Like X11 ListFontsWithInfo except that this request only
    --  returns information about fonts that can support the full
    --  range of PEX text attributes (i.e., those fonts that are
    --  "PEX usable")This list may or may not contain some of the
    --  same fonts returned by the X11 ListFonts request. This
    --  request returns a list of at most max_names entries, each
    --  of which contains information about a font matching the
    --  pattern . Pattern is a string that uses the ISO Latin-1
    --  encoding, and upper/lower case does not matter. In the
    --  pattern, the '?' character (octal value 77)will match any
    --  single character, and the character '*' (octal value
    --  52)will match any number of characters. The returned
    --  names are in lower case, and are also ISO Latin-1 encoded
    --  strings. The information returned for each font is
    --  identical to what PEXQueryFont would return.
    --
    --  <Parameters>
    --
    --  Display_Id     : The X Server connection.
    --  Pattern        : Specifies the string associated with the font names
    --                   that you want to be returned.
    --  Font_Info_List : The list of font records returned, one for each name
    --                   found.
    --  Names_List     : The list of names found matching the pattern.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Name is raised if no matching names are found.
    --
    --  <Called By>
    --
    --  External.
    --
    --=======================================================================

    procedure List_Fonts_With_Info ( Display_Id     : in X_Types.Display;
                                     Pattern        : in String;
                                     Font_Info_List : in out Font_Record_List;
                                     Names_List     : in out String_List ) ;

    --=======================================================================
    --  <Subprogram Name>
    --
    --  Query_Text_Extents
    --
    --  <Description>
    --
    --  This request generates a reply which contains extent
    --  information in the local 2D text coordinate system for
    --  each of the specified strings. If resource_id is a
    --  renderer or PHIGS workstation resource, the TextFont
    --  table used to perform the extents computation will be the
    --  TextFont table associated with the renderer or PHIGS
    --  workstation. If resource_id is a lookup table resource of
    --  type TextFont , it is used directly. Font_group provides
    --  the index of the entry that is to be used to obtain the
    --  font group. Stroke precision is assumed. The text
    --  position is (0,0)in the local 2D text coordinate system.
    --  Concat_point returns the point where the next glyph
    --  should go if the string is to be extended. This position
    --  is given in the 2D text coordinate system. (A suitable
    --  modeling transformation to account for the character up
    --  vector will still need to be applied by the client.)If a
    --  specified font has no defined default_glyph (that is, if
    --  default_glyph refers to a non-existent glyph) then
    --  undefined glyphs in strings are taken to have all zero
    --  metrics.
    --
    --  <Parameters>
    --
    --   Display_Id  : The X Server connection.
    --   Resource_Id : 
    --   Font        :  The font index to use.
    --   Path        :  The font path desired.
    --   Expansion   : 
    --   Spacing     : 
    --   Height      : 
    --   Alignment   : 
    --   Texts       : The text to evaluate extent.
    --   Extents     : The evaluated extent info returned.
    --
    --  <Exceptions Raised>
    --
    --  <Called By>
    --
    --  External.
    --
    --=======================================================================

    procedure Query_Text_Extents
        ( Display_Id  : in X_Types.Display;
          Resource_Id : in X_Types.Resource ;
          Font        : in Text_Font_Index;
          Path        : in Text_Path ;
          Expansion   : in Char_Expansion ;
          Spacing     : in Char_Spacing ;
          Height      : in Mc_Type ;
          Alignment   : in Text_Alignment ;
          Texts       : in Set_Of_Mono_Encoding_List;
          Extents     : out Extent_Info_List ) ;

end Pex_Fonts;
