---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
--   
--   Package : Pex_Information
--    
--   Version : 5.1
--    
--   Subject : PEX Extension Information functions
--
--        Open_Pex
--        Close_Pex
--
--   Section : 2.7 -- Extension Information
--    
--        Get_Extension_Info
--        Get_Enumerated_Type_Info
--        Get_Implementation_Dependant_Constants
--        Default_Implementation_Dependant_Constants
--     
--        Match_Renderer_Targets
--
with X_Types ;
with Pex_Types ;

package Pex_Information is

    use X_Types ;
    use Pex_Types ;

    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Open_Pex 
    --
    --  <Description>
    --
    --  Initialize a pex connection with a Pex server. A "List
    --  extension" request should be performed first to check the
    --  server supports Pex.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Open_Pex ( Display_Id : in Display ) ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Close_Pex 
    --
    --  <Description>
    --
    --  Should be called when the application has finished 
    --  with the Pex environment.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Close_Pex ( Display_Id : in Display ) ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Get_Enumerated_Type_Info
    --
    --  <Description>
    --
    --  
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Get_Enumerated_Type_Info 
        ( Display_Id  : in Display;
          Drawable_Id : in Drawable;
          Enum_Types  : in Enumerated_Types_Array;
          Types       : out Enumerated_Type_List);
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Get_Enumerated_Type_Info
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Get_Enumerated_Type_Info 
        ( Display_Id  : in Display;
          Drawable_Id : in Drawable;
          Enum_Types  : in Enumerated_Types_Array;
          Types       : out Set_Of_String_Lists);
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Get_Enumerated_Type_Info
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Get_Enumerated_Type_Info 
        ( Display_Id  : in Display;
          Drawable_Id : in Drawable;
          Enum_Types  : in Enumerated_Types_Array;
          Types       : out Enumerated_Type_Definition_List);
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Get_Implementation_Dependant_Constants
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Get_Implementation_Dependant_Constants
        ( Display_Id  : in Display;
          Example_Id  : in Drawable;
          Constants   : out Implementation_Constant_Values );
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Get_Implementation_Dependant_Constants
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    procedure Get_Implementation_Dependant_Constants
        ( Display_Id  : in Display;
          Example_Id  : in Drawable;
          Names       : in Implementation_Specific_Array;
          Constants   : out Implementation_Specific_List );
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Default_Implementation_Dependant_Constants
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Default_Implementation_Dependant_Constants
        (Display_Id  : in Display) return Implementation_Constant_Values ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Dithering_Supported 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Dithering_Supported (Display_Id : in Display)
        return Boolean ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Edge_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Edge_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Line_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Line_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Marker_Size 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Marker_Size (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Model_Clip_Planes 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Model_Clip_Planes (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Name_Set_Names 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Name_Set_Names (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Non_Ambient_Lights 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Non_Ambient_Lights (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_NURB_Order 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_NURB_Order (Display_Id : in Display)
        return Nurb_Order ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Trim_Curve_Order 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Trim_Curve_Order (Display_Id : in Display)
        return Trim_Order ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Min_Edge_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Min_Edge_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Min_Line_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Min_Line_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Min_Marker_Size 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Min_Marker_Size (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Nominal_Edge_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Nominal_Edge_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Nominal_Line_Width 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Nominal_Line_Width (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Nominal_Marker_Size 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Nominal_Marker_Size (Display_Id : in Display)
        return Pixels ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Num_Supported_Edge_Widths 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Num_Supported_Edge_Widths (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Num_Supported_Line_Widths 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Num_Supported_Line_Widths (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Num_Supported_Marker_Sizes 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Num_Supported_Marker_Sizes (Display_Id : in Display)
        return X_Natural ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Best_Color_Approximation 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Best_Color_Approximation (Display_Id : in Display)
        return Color_Best_Choice ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Transparency_Supported 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Transparency_Supported (Display_Id : in Display)
        return Boolean ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Double_Buffering_Supported 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Double_Buffering_Supported (Display_Id : in Display)
        return Boolean ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Max_Hits_Events_Supported 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Max_Hits_Events_Supported (Display_Id : in Display)
        return Boolean ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Red_U 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Red_U (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Red_V 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Red_V (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Luminance_Red 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Luminance_Red (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Green_U 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Green_U (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Green_V 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Green_V (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Luminance_Green 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Luminance_Green (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Blue_U 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Blue_U (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_Blue_V 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_Blue_V (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Luminance_Blue 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Luminance_Blue (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_White_U 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_White_U (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Chromaticity_White_V 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Chromaticity_White_V (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Luminance_White 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Luminance_White (Display_Id : in Display)
        return Color_Float_Value ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Implementation_Subset 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Implementation_Subset ( Display_Id : in Display )
        return Subset_Info_Mask ;
    
    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Level_Of_This_Pex_Implementation 
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=============================================================== =====

    function Level_Of_This_Pex_Implementation ( Display_Id : in Display )
        return Implementation_Level ;
    
    --=============================================================== ====
    --  <Subprogram Name>
    --
    --  Protocol_Revision
    --
    --  <Description>
    --
    --  This function is used to return the minor protocol revision (0) of the
    --  PEX Server.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --
    --  <Exceptions Raised>
    --
    --  none.
    --
    --=============================================================== ====

    function Protocol_Revision (Display_Id : in Display) return Natural;


    --=============================================================== =====
    --  <Subprogram Name>
    --
    --  Protocol_Version
    --
    --  <Description>
    --
    --  This function is used to return the major version number (5) of the
    --  PEX Protocol associated with the connected Display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --
    --  <Exceptions Raised>
    --
    --  none.
    --
    --=============================================================== ========

    function Protocol_Version (Display_Id : in Display) return Natural;

    
    --=============================================================== ========
    --  <Subprogram Name>
    --
    --  Server_Vendor
    --
    --  <Description>
    --
    --  This function is used to return a string that provides some
    --  identification of the owner of the PEX Server implementation.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --
    --  <Exceptions Raised>
    --
    --  none.
    --
    --=============================================================== ========

    function Server_Vendor (Display_Id : in Display) return String;
    
    
    --=============================================================== ========
    --  <Subprogram Name>
    --
    --  Vendor_Release
    --
    --  <Description>
    --
    --  This function is used to return a number related to a vendor's
    --  release of the PEX Server.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --
    --  <Exceptions Raised>
    --
    --  none.
    --
    --=============================================================== ========

    function Vendor_Release (Display_Id : in Display) return Natural;
    
    --=============================================================== ========
    --  <Subprogram Name>
    --
    --  Match_Renderer_Targets
    --
    --  <Description>
    --
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the connection to the X Server.
    --  Example_Id  : 
    --  Profile     : 
    --  Matchings   : 
    --  Num_Targets : 
    --
    --
    --  <Exceptions Raised>
    --
    --  none.
    --
    --=============================================================== ========
    
    procedure Match_Renderer_Targets
        ( Display_Id  : in Display;
          Example_Id  : in Drawable;
          Profile     : in Renderer_Target ;
          Matchings   : out Renderer_Targets ;
          Last_Target : out X_Natural ) ;

end Pex_Information ;
