---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
--
--   Package : Pex_Search
--
--   Version :
--
--   Subject : Search Contexts
--
--   Section 9.1 -- Search Context Resource Management
--   Create_Search_Context
--   Copy_Search_Context
--   Delete_Search_Context
--
--   Section 9.2 -- Search Context Inquiry
--   Get_Search_Context
--
--   Section 9.3 -- Search Context Modification
--   Change_Search_Context
--
--   Section 9.4 -- Structure Network Searching
--   Search_Network
--
-- 
with X_Types;
with Pex_Types;
-- 
package Pex_Search is 
-- 
    use X_Types;
    use Pex_Types;
-- 
--   Section 9.1 -- Search Context Resource Management
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Create_Search_Context
    --
    --  <Description>
    --
    --  This request creates a search context resource for the
    --  returned  sc_id . The item_mask defines those search
    --  context attributes that are to be explicitly set at the
    --  time the resource is created. The item_list contains the
    --  corresponding list of values used to modify the
    --  newly-created search context. Floating point values in
    --  item_list will be in the floating point format specified
    --  in fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Mask       : Selection of attributes to set at creation.
    --  Values     : Values of the selected attributes.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    function Create_Search_Context
        ( Display_Id : in Display;
          Mask       : in Search_Context_Bitmask;
          Values     : in Search_Context_Values) return Search_Context;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Copy_Search_Context
    --
    --  <Description>
    --
    --  This request copies the source search context src_sc_id
    --  to a destination search context dest_sc_id . The
    --  dest_sc_id must already exist as a valid resource. The
    --  item_mask indicates which values in the search context
    --  will be copied.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Search_Src : The original search context.
    --  Search_Dst : The destination search context.
    --  Mask       : Selection of attributes to copy.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Copy_Search_Context ( Display_Id : in Display;
                                    Search_Src : in Search_Context;
                                    Search_Dst : in Search_Context;
                                    Mask       : in Search_Context_Bitmask);
  
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Free_Search_Context
    --
    --  <Description>
    --
    --  This request deletes the specified search context
    --  resource and frees the storage associated with it. 
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Search_Id  : The search context to delete.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Free_Search_Context ( Display_Id : in Display;
                                    Search_Id  : in Search_Context);
    
-- 
--     Section 9.2 -- Search Context Inquiry
--   
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Search_Context
    --
    --  <Description>
    --
    --  This request will return components of the search context
    --  specified by sc_id . The item_mask specifies which
    --  components are to be inquired and returned. The specified
    --  attributes of the search context will be returned in
    --  item_list . Floating point values in item_list will be
    --  returned in the floating point format specified in
    --  fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Search_Id  : The search context to inquire about.
    --  Mask       : Selection of requested attributes.
    --  Values     : Values returned.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Search_Context ( Display_Id : in Display;
                                   Search_Id  : in Search_Context;
                                   Mask       : in Search_Context_Bitmask;
                                   Values     : in out Search_Context_Values);
    
--
--   Section 9.3 -- Search Context Modification
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Change_Search_Context
    --
    --  <Description>
    --
    --  This request changes components of a search context. The
    --  item_mask and item_list specify which components are to
    --  be changed. Each bit in the item_mask indicates whether
    --  or not there is a corresponding entry in the item_list .
    --  It is therefore possible to modify one or many search
    --  context attributes with a PEXChangeSearchContext request.
    --  Floating point values in item_list will be in the
    --  floating point format specified in fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Search_Id  : The search context.
    --  Mask       : Selection of attributes to modify.
    --  Values     : Values to set.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Change_Search_Context ( Display_Id : in Display;
                                      Search_Id  : in Search_Context;
                                      Mask       : in Search_Context_Bitmask;
                                      Values     : in Search_Context_Values);
    
-- 
--   Section 9.4 -- Structure Network Searching
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Search_Network
    --
    --  <Description>
    --
    --  This request causes a spatial search in world coordinates
    --  to be performed on a structure network. The parameters of
    --  the searching operation are found in the search context
    --  sc_id . The search begins at the element following the
    --  one indicated by the start_path attribute of sc_id . The
    --  search is terminated once the end of the structure
    --  indicated by search_ceiling has been reached. The first
    --  element that meets the search criteria is returned in
    --  found_path . If no element is found, found_path will be
    --  null. After the search has completed, the start_path
    --  attribute of sc_id will be set to the value that is
    --  returned in found_path . For a structure element to be
    --  considered a candidate for the search, the current name
    --  set has to be accepted by all the name set pairs in the
    --  search context's normal_list , and has to be rejected by
    --  all of the name set pairs in the inverted_list . If the
    --  normal_list is Null , all possible name sets are accepted
    --  by the normal list. If the inverted_list is Null , all
    --  possible name sets are accepted by the inverted list.
    --  Therefore the default case is that all output primitives
    --  are considered.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Search_Id  : The search context.
    --  El_Refs    : Element_Path returned.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Search_Network ( Display_Id : in Display;
                               Search_Id  : in Search_Context;
                               El_Refs    : out Element_Path);
end Pex_Search;
