---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
-- Derivation   : MIT X Window System, V11.R4
--
-- This Ada language binding to the X Window System inherits
-- the MIT copyright. The following copyright must be included
-- in all software utilising this binding.
--
-- Copyright 1990, 1991 J.C. Mahieux and B. Maudry
-- Copyright 1985, 1986, 1987 by the Massachusetts Institute of Technology
--
with X_Types ;

package X_Window_Manager is
use X_Types ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Add_To_Save_Set
    --
    --  <Description>
    --
    -- This procedure adds a window to a client's save save-set.
    -- It is primarily used by window managers.
    --
    --  <Parameters>
    --
    --  Display_Id     : Specifies the connection to the X Server.
    --  Window_Id      : Specifies the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if either window Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Add_To_Save_Set ( Display_Id : in Display;
                                Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Change_Active_Pointer_Grab
    --
    --  <Description>
    --
    --  This procedure is used to change the specified dynamic parameters
    --  if the pointer is actively grabbed by the client and if the
    --  specified time is no earlier than the last pointer grab and no
    --  later than the current X server time.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Change_Active_Pointer_Grab
        ( Display_Id  : in Display;
          Grab_Events : in Event_Mask_Type;
          Cursor_Id   : in Cursor;
          Grab_Time   : in Time);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Change_Pointer_Control 
    --
    --  <Description>
    --
    --  This procedure is used to control the interactive feel of the
    --  pointer device.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Change_Pointer_Control ( Display_Id   : in Display;
                                       Do_Accel     : in Boolean;
                                       Do_Threshold : in Boolean;
                                       Numerator    : in Pointer_Motion;
                                       Denominator  : in Pointer_Motion;
                                       Threshold    : in Pointer_Motion ) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Change_Save_Set
    --
    --  <Description>
    --
    -- This procedure adds or removes a window from the client's save set.
    -- It is primarily used by window managers.
    --
    --  <Parameters>
    --
    --  Display_Id     : Specifies the connection to the X Server.
    --  Window_Id      : Specifies the window.
    --  Mode           : Specifies the change mode.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if either window Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Change_Save_Set ( Display_Id : in Display;
                                Window_Id  : in Window;
                                Mode       : in Change_Mode);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Fetch_Name
    --
    --  <Description>
    --
    --  This function gets the name of a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Fetch_Name ( Display_Id : in Display;
                          Window_Id  : in Window) return String;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Class_Hint
    --
    --  <Description>
    --
    --  This procedure gets the class of a window.
    --
    --  <Parameters>
    --
    --  Display_Id    : Specifies the X Server connection.
    --  Window_Id     : Specifies the Window.
    --  Class_Hints   : Returns the class hints for the window.
    --  Success       : Return True if the hints were found
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Class_Hint ( Display_Id    : in Display;
                               Window_Id     : in Window;
                               Class_Hints   : out Wm_Class_Hint_Record;
                               Success       : out Boolean) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Icon_Name
    --
    --  <Description>
    --
    --  This function gets the name a window wants displayed in its icon.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Get_Icon_Name ( Display_Id : in Display;
                             Window_Id  : in Window) return String;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Icon_Sizes
    --
    --  <Description>
    --
    --  This function gets the value of the icon size atom.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Get_Icon_Sizes ( Display_Id : in Display;
                              Window_Id  : in Window)
        return Icon_Size_List ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Input_Focus
    --
    --  <Description>
    --
    --  This procedure is used to return the focus window Id and the
    --  current focus state.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Get_Input_Focus ( Display_Id : in Display;
                                Focus      : out Window;
                                Mode       : out Revert_Mode);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Normal_Hints
    --
    --  <Description>
    --
    --  This procedure gets the size hints for a window in its normal state.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Supplied   : returns the mask of hints the server is able to fill
    --  Hints      : Returns the hints for the window (if found).
    --  Success    : Return True if the hints were found
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Normal_Hints ( Display_Id  : in Display;
                                 Window_Id   : in Window;
                                 Supplied    : out Size_Hint_Mask_Type;
                                 Hints       : out Size_Hint_Record;
                                 Success     : out Boolean) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Pointer_Control
    --
    --  <Description>
    --
    --  This procedure is used to return the pointer's current acceleration
    --  multiplier and acceleration threshold.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Pointer_Control ( Display_Id  : in Display ;
                                    Numerator   : out Pointer_Motion ;
                                    Denominator : out Pointer_Motion ;
                                    Threshold   : out Pointer_Motion ) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Pointer_Mapping
    --
    --  <Description>
    --
    --  This procedure is used to return the current mapping of the
    --  pointer.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Get_Pointer_Mapping ( Display_Id : in Display;
                                    Map        : in out Map_Array;
                                    Status     : out Map_Status);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Size_Hints
    --
    --  <Description>
    --
    --  This procedure gets the value of any size hint property.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Property   : Specifies which property to get.
    --  Supplied   : returns the mask of hints the server is able to fill
    --  Hints      : Returns the hints for the window.
    --  Success    : Return True if the hints were found
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Size_Hints ( Display_Id  : in Display;
                               Window_Id   : in Window;
                               Property    : in Atom;
                               Supplied    : out Size_Hint_Mask_Type;
                               Hints       : out Size_Hint_Record;
                               Success     : out Boolean) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Transient_For_Hint
    --
    --  <Description>
    --
    --  This procedure gets the transient hint for a window.
    --
    --  <Parameters>
    --
    --  Display_Id     : Specifies the X Server connection.
    --  Window_Id      : Specifies the Window.
    --  Prop_Window    : Returns the window id that transient hint is set in.
    --  Success        : Return True if the hints were found
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Transient_For_Hint ( Display_Id     : in Display;
                                       Window_Id      : in Window;
                                       Prop_Window    : out Window;
                                       Success        : out Boolean) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Wm_Hints
    --
    --  <Description>
    --
    --  This function gets the window manager hints property.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Access is raised if the property was never set.
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Get_Wm_Hints ( Display_Id : in Display;
                            Window_Id  : in Window) return Wm_Hint_Record;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Zoom_Hints
    --
    --  <Description>
    --
    --  This procedure gets the zoom hints for a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Supplied   : returns the mask of hints the server is able to fill
    --  Hints      : Returns the hints for the window (if found).
    --  Success    : Return True if the hints were found
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Zoom_Hints ( Display_Id  : in Display;
                               Window_Id   : in Window;
                               Supplied    : out Size_Hint_Mask_Type;
                               Hints       : out Size_Hint_Record;
                               Success     : out Boolean) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Grab_Button
    --
    --  <Description>
    --
    --  This procedure is used to establish a passive grab on a mouse
    --  button.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Grab_Button ( Display_Id    : in Display;
                            Button        : in Button_Name_Type;
                            Modifiers     : in Key_And_Button_Mask;
                            Window_Id     : in Window;
                            Owner_Events  : in Boolean;
                            Grab_Events   : in Event_Mask_Type;
                            Pointer_Mode  : in Grab_Mode;
                            Keyboard_Mode : in Grab_Mode;
                            Confine_To    : in Window;
                            Cursor_Id     : in Cursor);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Grab_Key
    --
    --  <Description>
    --
    --  This procedure is used to passively grab a single key of the
    --  keyboard.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Grab_Key ( Display_Id    : in Display;
                         Key           : in Keycode;
                         Modifiers     : in Key_And_Button_Mask;
                         Owner_Events  : in Boolean;
                         Window_Id     : in Window;
                         Pointer_Mode  : in Grab_Mode;
                         Keyboard_Mode : in Grab_Mode);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Grab_Keyboard
    --
    --  <Description>
    --
    --  This function is used to actively grab control of the main
    --  keyboard and generates Focus_In and Focus_Out events.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    function Grab_Keyboard ( Display_Id    : in Display;
                             Window_Id     : in Window;
                             Owner_Events  : in Boolean;
                             Pointer_Mode  : in Grab_Mode;
                             Keyboard_Mode : in Grab_Mode;
                             Grab_Time     : in Time)
        return Grab_Reply_Status;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Grab_Pointer
    --
    --  <Description>
    --
    --  This function is used to actively grab control of the pointer.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    function Grab_Pointer ( Display_Id    : in Display;
                            Window_Id     : in Window;
                            Owner_Events  : in Boolean;
                            Grab_Events   : in Event_Mask_Type;
                            Pointer_Mode  : in Grab_Mode;
                            Keyboard_Mode : in Grab_Mode;
                            Confine_To    : in Window;
                            Cursor_Id     : in Cursor;
                            Grab_Time     : in Time)
        return Grab_Reply_Status;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Grab_Server
    --
    --  <Description>
    --
    --  This procedure is used to disable processing of requests and
    --  close-downs on all other connections than the one this request
    --  arrived on.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Grab_Server (Display_Id : in Display) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Kill_Client
    --
    --  <Description>
    --
    --  This procedure is used to forces a close-down of the client that
    --  created the resource if a valid resource is specified.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Kill_Client ( Display_Id  : in Display;
                            Resource_Id : in Resource) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Remove_From_Save_Set
    --
    --  <Description>
    --
    -- This procedure removes a window from a client's save save-set.
    -- It is primarily used by window managers.
    --
    --  <Parameters>
    --
    --  Display_Id     : Specifies the connection to the X Server.
    --  Window_Id      : Specifies the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if either window Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Remove_From_Save_Set ( Display_Id : in Display;
                                     Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Class_Hint
    --
    --  <Description>
    --
    --  This procedure sets the class of a window.
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the X Server connection.
    --  Window_Id   : Specifies the Window.
    --  Class_Hints : Specifies the class hints for the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Class_Hint ( Display_Id  : in Display;
                               Window_Id   : in Window;
                               Class_Hints : in Wm_Class_Hint_Record);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Close_Down_Mode
    --
    --  <Description>
    --
    --  This procedure is used to define what will happen to the clients
    --  resources at connection close.
    --
    --  <Called By>
    --
    --  External.
    --

    --====================================================================

    procedure Set_Close_Down_Mode ( Display_Id : in Display;
                                    Mode       : in Close_Mode) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Command
    --
    --  <Description>
    --
    --  This procedure sets the value of the command atom.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Command    : Specifies the command and arguments used
    --               to start the application
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Command ( Display_Id : in Display;
                            Window_Id  : in Window;
                            Command    : in String_List);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Icon_Name
    --
    --  <Description>
    --
    --  This procedure Sets the name to be displayed in a window's icon.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Name       : Specifies the name of the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Icon_Name ( Display_Id : in Display;
                              Window_Id  : in Window;
                              Name       : in String) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Icon_Sizes
    --
    --  <Description>
    --
    --  This procedure sets the value of the icon size atom.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Size_List  : Specifies the icon sizes.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Icon_Sizes ( Display_Id : in Display;
                               Window_Id  : in Window;
                               Size_List  : in Icon_Size_List);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Input_Focus
    --
    --  <Description>
    --
    --  This procedure is used to change the input focus and the last
    --  focus-change time.  The function has no effect if the specified
    --  time is earlier than the last-focus change time of the most recent
    --  active grab for that client, or if the specified time is later
    --  than the current X server time.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Set_Input_Focus ( Display_Id : in Display;
                                Focus      : in Window;
                                Mode       : in Revert_Mode;
                                Grab_Time  : in Time);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Normal_Hints
    --
    --  <Description>
    --
    --  This procedure sets the size hints for a window in its normal state.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Hints      : Specifies the hints for the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Normal_Hints ( Display_Id : in Display;
                                 Window_Id  : in Window;
                                 Hints      : in Size_Hint_Record);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Pointer_Mapping
    --
    --  <Description>
    --
    --  This procedure is used to set the mapping of the pointer and
    --  causes a MAPPING_NOTIFY event on a status of MAPPING_SUCCESS.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Set_Pointer_Mapping ( Display_Id : in Display;
                                    Map        : in Map_Array;
                                    Status     : out Map_Status);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Size_Hints
    --
    --  <Description>
    --
    --  This procedure sets the value of any size hint property.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Hints      : Specifies the hints for the window.
    --  Property   : Specifies which property to set.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Size_Hints ( Display_Id : in Display;
                               Window_Id  : in Window;
                               Hints      : in Size_Hint_Record;
                               Property   : in Atom);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Standard_Properties
    --
    --  <Description>
    --
    --  This procedure specifies a minimum set of properties describing the
    --  "quickie" application.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  W_Name     : Specifies the name of the window.
    --  Icon_Name  : Specifies the name of the icon.
    --  Icon       : Specifies the icon to be used.
    --  Command    : Specifies the command and arguments used
    --               to start the application
    --  Hints      : Specifies the sizing hints for the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Standard_Properties ( Display_Id : in Display;
                                        Window_Id  : in Window;
                                        W_Name     : in String;
                                        Icon_Name  : in String;
                                        Icon       : in Pixmap;
                                        Command    : in String_List;
                                        Hints      : in Size_Hint_Record);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Transient_For_Hint
    --
    --  <Description>
    --
    --  This procedure sets the transient hint for a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Prop_Window: Specifies the window that transient hint is to be set in.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Transient_For_Hint ( Display_Id  : in Display;
                                       Window_Id   : in Window;
                                       Prop_Window : in Window);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Wm_Hints
    --
    --  <Description>
    --
    --  This procedure sets the window manager hints property.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Hints      : Specifies the hints for the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Wm_Hints ( Display_Id : in Display;
                             Window_Id  : in Window;
                             Hints      : in Wm_Hint_Record) ;
    
    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Zoom_Hints
    --
    --  <Description>
    --
    --  This procedure sets the zoom hints for a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Hints      : Specifies the hints for the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Zoom_Hints ( Display_Id : in Display;
                               Window_Id  : in Window;
                               Hints      : in Size_Hint_Record);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Store_Name
    --
    --  <Description>
    --
    --  This procedure assigns a name to a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the X Server connection.
    --  Window_Id  : Specifies the Window.
    --  Name       : Specifies the name of the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Store_Name ( Display_Id : in Display;
                           Window_Id  : in Window;
                           Name       : in String);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Ungrab_Button
    --
    --  <Description>
    --
    --  This procedure is used to release the passive button/key
    --  combination on the specified window if it was grabbed by
    --  this client.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Ungrab_Button ( Display_Id : in Display;
                              Button     : in Button_Name_Type;
                              Modifiers  : in Key_And_Button_Mask;
                              Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Ungrab_Key
    --
    --  <Description>
    --
    --  This procedure is used to release the key combination on the
    --  specified window if it was grabbed by this client.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Ungrab_Key ( Display_Id : in Display;
                           Key        : in Keycode;
                           Modifiers  : in Key_And_Button_Mask;
                           Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Ungrab_Keyboard
    --
    --  <Description>
    --
    --  This procedure is used to release the keyboard and any queued
    --  events if this client has it actively grabbed from either
    --  Grab_Keyboard or Grab_Key.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Ungrab_Keyboard ( Display_Id  : in Display;
                                Ungrab_Time : in Time) ;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Ungrab_Pointer
    --
    --  <Description>
    --
    --  This procedure is used to release the pointer and any queued
    --  events if this client has actively grabbed the pointer from
    --  Grab_Pointer, Grab_Button, or from a normal button press.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Ungrab_Pointer ( Display_Id  : in Display;
                               Ungrab_Time : in Time);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Ungrab_Server
    --
    --  <Description>
    --
    --  This procedure is used to restart processing of requests and close
    --  downs on other connections.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Ungrab_Server (Display_Id : in Display) ;
    
    
    --====================================================================
    --  <Subprogram Name>
    --
    --  Warp_Pointer
    --
    --  <Description>
    --
    --  This procedure is used to move the pointer to the coordinates
    --  specified by the Dest_Xy argument, relative to the destination
    --  window's origin.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================
    procedure Warp_Pointer ( Display_Id    : in Display;
                             Source        : in Window;
                             Destination   : in Window;
                             Source_Bounds : in Rectangle;
                             Dest_Xy       : in Point);


end X_Window_Manager;
